var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

import React, { PropTypes as PT } from 'react';

import css from '../../styles/game.css';

export function UnityEmbed(_ref) {
	var content = _ref.content;

	var unityInstalled = typeof navigator !== 'undefined' && navigator.mimeTypes && navigator.mimeTypes['application/vnd.unity'] && navigator.mimeTypes['application/vnd.unity'].enabledPlugin && navigator.plugins && navigator.plugins['Unity Player'];

	if (!unityInstalled) {
		return React.createElement(
			'div',
			{ className: css.notInstalled },
			React.createElement(
				'p',
				null,
				'Unity Web Player not installed.'
			)
		);
	}

	return React.createElement('embed', {
		type: 'application/vnd.unity',
		src: content
	});
}

UnityEmbed.propTypes = {
	content: PT.string
};

export function FlashEmbed(_ref2) {
	var content = _ref2.content;

	return React.createElement(
		'object',
		{ data: content },
		React.createElement('param', { name: 'movie', value: content }),
		React.createElement('param', { name: 'allowScriptAccess', value: 'always' }),
		React.createElement('param', { name: 'allowNetworking', value: 'internal' })
	);
}

FlashEmbed.propTypes = {
	content: PT.string
};

export default function Game(_ref3) {
	var className = _ref3.className,
	    content = _ref3.content,
	    height = _ref3.height,
	    type = _ref3.type,
	    width = _ref3.width,
	    props = _objectWithoutProperties(_ref3, ['className', 'content', 'height', 'type', 'width']);

	var classes = [css.container];
	if (className) {
		classes.push(className);
	}

	return React.createElement(
		'div',
		{ className: classes.join(' '), style: { width: width, height: height } },
		type === 'flash' ? React.createElement(FlashEmbed, _extends({}, props, { content: content })) : type === 'unity' ? React.createElement(UnityEmbed, _extends({}, props, { content: content })) : type === 'iframe' ? React.createElement('iframe', { src: content, width: width, height: height }) : 'unsupported game type'
	);
}

Game.propTypes = {
	/**
  * Additional class names
  */
	className: PT.string,

	/**
  * URL to the content
  */
	content: PT.string.isRequired,

	/**
  * Height of the game
  */
	height: PT.number.isRequired,

	/**
  * Type of the game
  */
	type: PT.oneOf(['flash', 'unity', 'iframe']).isRequired,

	/**
  * Width of the game
  */
	width: PT.number.isRequired
};