import React, { PropTypes as PT } from 'react';
import { Link } from 'react-router';

import css from '../../styles/menu.css';

export default function MenuItem(_ref) {
	var label = _ref.label,
	    url = _ref.url,
	    children = _ref.children,
	    isActive = _ref.isActive,
	    className = _ref.className;

	var classes = [css.menuItem];

	if (isActive) {
		classes.push(css.menuItemActive);
	}

	if (className) {
		classes.push(className);
	}

	return React.createElement(
		'div',
		null,
		React.createElement(
			Link,
			{ to: url, className: classes.join(' ') },
			label
		),
		children
	);
}

MenuItem.propTypes = {
	/**
  * Children of the MenuItem
  */
	children: PT.node,

	/**
  * Additional className
  */
	className: PT.string,

	/**
  * URL that the MenuItem links to
  */
	url: PT.string.isRequired,

	/**
  * Whether this menu item is currently active
  */
	isActive: PT.bool,

	/**
  * Label of the MenuItem
  */
	label: PT.string.isRequired
};

MenuItem.defaultProps = {
	isActive: false
};